# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## v1.1.0

### Added

Ausgabe in der Konsole jetzt farbig und detaillierter.


## v1.0.2 - 2023-05-22

### Added
Automatisches publishing zu pypi mit gh actions

## v1.0.1 - 2023-05-22

### Added
Release worflow mit artifakten mittels gh actions

## v1.0.0 - 2023-05-22
Erste Version
### Added
